# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.132
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from nuon.models.app_installer_metadata import AppInstallerMetadata

class TestAppInstallerMetadata(unittest.TestCase):
    """AppInstallerMetadata unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AppInstallerMetadata:
        """Test AppInstallerMetadata
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AppInstallerMetadata`
        """
        model = AppInstallerMetadata()
        if include_optional:
            return AppInstallerMetadata(
                community_url = '',
                copyright_markdown = '',
                created_at = '',
                created_by = nuon.models.app/user_token.app.UserToken(
                    created_at = '', 
                    created_by_id = '', 
                    email = '', 
                    expires_at = '', 
                    id = '', 
                    issued_at = '', 
                    issuer = '', 
                    subject = '', 
                    token_type = 'auth0', 
                    updated_at = '', ),
                created_by_id = '',
                demo_url = '',
                description = '',
                documentation_url = '',
                favicon_url = '',
                footer_markdown = '',
                formatted_demo_url = '',
                github_url = '',
                homepage_url = '',
                id = '',
                installer_id = '',
                logo_url = '',
                name = '',
                post_install_markdown = '',
                updated_at = ''
            )
        else:
            return AppInstallerMetadata(
        )
        """

    def testAppInstallerMetadata(self):
        """Test AppInstallerMetadata"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
