# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.15
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from nuon.api.apps_api import AppsApi


class TestAppsApi(unittest.TestCase):
    """AppsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AppsApi()

    def tearDown(self) -> None:
        pass

    def test_create_app(self) -> None:
        """Test case for create_app

        create an app
        """
        pass

    def test_create_app_input_config(self) -> None:
        """Test case for create_app_input_config

        """
        pass

    def test_create_app_installer(self) -> None:
        """Test case for create_app_installer

        create an app installer
        """
        pass

    def test_create_app_runner_config(self) -> None:
        """Test case for create_app_runner_config

        create an app runner config
        """
        pass

    def test_create_app_sandbox_config(self) -> None:
        """Test case for create_app_sandbox_config

        create an app sandbox config
        """
        pass

    def test_delete_app(self) -> None:
        """Test case for delete_app

        delete an app
        """
        pass

    def test_delete_app_installer(self) -> None:
        """Test case for delete_app_installer

        delete an app installer
        """
        pass

    def test_get_app(self) -> None:
        """Test case for get_app

        get an app
        """
        pass

    def test_get_app_input_configs(self) -> None:
        """Test case for get_app_input_configs

        get app input configs
        """
        pass

    def test_get_app_input_latest_config(self) -> None:
        """Test case for get_app_input_latest_config

        get latest app input config
        """
        pass

    def test_get_app_installer(self) -> None:
        """Test case for get_app_installer

        get an app installer
        """
        pass

    def test_get_app_runner_configs(self) -> None:
        """Test case for get_app_runner_configs

        get app runner configs
        """
        pass

    def test_get_app_runner_latest_config(self) -> None:
        """Test case for get_app_runner_latest_config

        get latest app runner config
        """
        pass

    def test_get_app_sandbox_configs(self) -> None:
        """Test case for get_app_sandbox_configs

        get app sandbox configs
        """
        pass

    def test_get_app_sandbox_latest_config(self) -> None:
        """Test case for get_app_sandbox_latest_config

        get latest app sandbox config
        """
        pass

    def test_get_apps(self) -> None:
        """Test case for get_apps

        get all apps for the current org
        """
        pass

    def test_render_app_installer(self) -> None:
        """Test case for render_app_installer

        render an app installer
        """
        pass

    def test_update_app(self) -> None:
        """Test case for update_app

        update an app
        """
        pass

    def test_update_app_installer(self) -> None:
        """Test case for update_app_installer

        update an app installer
        """
        pass


if __name__ == '__main__':
    unittest.main()
