# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.15
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from nuon.api.sandboxes_api import SandboxesApi


class TestSandboxesApi(unittest.TestCase):
    """SandboxesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SandboxesApi()

    def tearDown(self) -> None:
        pass

    def test_get_sandbox(self) -> None:
        """Test case for get_sandbox

        get a sandbox
        """
        pass

    def test_get_sandbox_releases(self) -> None:
        """Test case for get_sandbox_releases

        get sandbox releases
        """
        pass

    def test_get_sandboxes(self) -> None:
        """Test case for get_sandboxes

        get all sandboxes
        """
        pass


if __name__ == '__main__':
    unittest.main()
