# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.15
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from nuon.api.orgs_api import OrgsApi


class TestOrgsApi(unittest.TestCase):
    """OrgsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = OrgsApi()

    def tearDown(self) -> None:
        pass

    def test_add_user(self) -> None:
        """Test case for add_user

        Add a user to the current org
        """
        pass

    def test_create_org(self) -> None:
        """Test case for create_org

        create a new org
        """
        pass

    def test_delete_org(self) -> None:
        """Test case for delete_org

        Delete an org
        """
        pass

    def test_get_org(self) -> None:
        """Test case for get_org

        Get an org
        """
        pass

    def test_get_orgs(self) -> None:
        """Test case for get_orgs

        Return current user's orgs
        """
        pass

    def test_update_org(self) -> None:
        """Test case for update_org

        Update current org
        """
        pass


if __name__ == '__main__':
    unittest.main()
