# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.153
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from nuon.models.app_app_input_group import AppAppInputGroup

class TestAppAppInputGroup(unittest.TestCase):
    """AppAppInputGroup unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AppAppInputGroup:
        """Test AppAppInputGroup
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AppAppInputGroup`
        """
        model = AppAppInputGroup()
        if include_optional:
            return AppAppInputGroup(
                app_input_id = '',
                app_inputs = [
                    nuon.models.app/app_input.app.AppInput(
                        app_input_id = '', 
                        created_at = '', 
                        created_by = nuon.models.app/user_token.app.UserToken(
                            created_at = '', 
                            created_by_id = '', 
                            email = '', 
                            expires_at = '', 
                            id = '', 
                            issued_at = '', 
                            issuer = '', 
                            subject = '', 
                            token_type = 'auth0', 
                            updated_at = '', ), 
                        created_by_id = '', 
                        default = '', 
                        description = '', 
                        display_name = '', 
                        group = nuon.models.app/app_input_group.app.AppInputGroup(
                            app_input_id = '', 
                            created_at = '', 
                            created_by_id = '', 
                            description = '', 
                            display_name = '', 
                            id = '', 
                            is_default = True, 
                            name = '', 
                            org_id = '', 
                            updated_at = '', ), 
                        group_id = '', 
                        id = '', 
                        name = '', 
                        org_id = '', 
                        required = True, 
                        sensitive = True, 
                        updated_at = '', )
                    ],
                created_at = '',
                created_by = nuon.models.app/user_token.app.UserToken(
                    created_at = '', 
                    created_by_id = '', 
                    email = '', 
                    expires_at = '', 
                    id = '', 
                    issued_at = '', 
                    issuer = '', 
                    subject = '', 
                    token_type = 'auth0', 
                    updated_at = '', ),
                created_by_id = '',
                description = '',
                display_name = '',
                id = '',
                is_default = True,
                name = '',
                org_id = '',
                updated_at = ''
            )
        else:
            return AppAppInputGroup(
        )
        """

    def testAppAppInputGroup(self):
        """Test AppAppInputGroup"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
